@@ -17,7 +17,6 @@
 
 #include <cstdint>
 
-#include "eckit/memory/NonCopyable.h"
 #include "eckit/os/Semaphore.h"
 
 #include "eckit/memory/Padded.h"
@@ -35,7 +34,7 @@ namespace eckit {
 /// Maps an array to shared memory
 
 template <class T>
-class SharedMemArray : private NonCopyable {
+class SharedMemArray {
 public:  // types
 
     using iterator       = T*;
@@ -45,6 +44,11 @@ public:  // methods
 
     SharedMemArray(const PathName&, const std::string& shmName, size_t);
 
+    SharedMemArray(const SharedMemArray&)            = delete;
+    SharedMemArray& operator=(const SharedMemArray&) = delete;
+    SharedMemArray(SharedMemArray&&)                 = delete;
+    SharedMemArray& operator=(SharedMemArray&&)      = delete;
+
     ~SharedMemArray();
 
     void sync();
